@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -74,7 +74,7 @@ __all__ = ("ServiceDiscoveryClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -99,7 +99,7 @@ class Exceptions:
 
 class ServiceDiscoveryClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html)
     """
 
@@ -115,7 +115,7 @@ class ServiceDiscoveryClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#can_paginate)
         """
 
@@ -123,14 +123,14 @@ class ServiceDiscoveryClient(BaseClient):
         self,
         *,
         Name: str,
-        CreatorRequestId: str = None,
-        Description: str = None,
-        Tags: List["TagTypeDef"] = None
+        CreatorRequestId: str = ...,
+        Description: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateHttpNamespaceResponseTypeDef:
         """
         Creates an HTTP namespace.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.create_http_namespace)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.create_http_namespace)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#create_http_namespace)
         """
 
@@ -139,16 +139,16 @@ class ServiceDiscoveryClient(BaseClient):
         *,
         Name: str,
         Vpc: str,
-        CreatorRequestId: str = None,
-        Description: str = None,
-        Tags: List["TagTypeDef"] = None,
-        Properties: "PrivateDnsNamespacePropertiesTypeDef" = None
+        CreatorRequestId: str = ...,
+        Description: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        Properties: "PrivateDnsNamespacePropertiesTypeDef" = ...
     ) -> CreatePrivateDnsNamespaceResponseTypeDef:
         """
         Creates a private namespace based on DNS, which is visible only inside a
         specified Amazon VPC.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.create_private_dns_namespace)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.create_private_dns_namespace)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#create_private_dns_namespace)
         """
 
@@ -156,15 +156,15 @@ class ServiceDiscoveryClient(BaseClient):
         self,
         *,
         Name: str,
-        CreatorRequestId: str = None,
-        Description: str = None,
-        Tags: List["TagTypeDef"] = None,
-        Properties: "PublicDnsNamespacePropertiesTypeDef" = None
+        CreatorRequestId: str = ...,
+        Description: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        Properties: "PublicDnsNamespacePropertiesTypeDef" = ...
     ) -> CreatePublicDnsNamespaceResponseTypeDef:
         """
         Creates a public namespace based on DNS, which is visible on the internet.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.create_public_dns_namespace)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.create_public_dns_namespace)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#create_public_dns_namespace)
         """
 
@@ -172,19 +172,19 @@ class ServiceDiscoveryClient(BaseClient):
         self,
         *,
         Name: str,
-        NamespaceId: str = None,
-        CreatorRequestId: str = None,
-        Description: str = None,
-        DnsConfig: "DnsConfigTypeDef" = None,
-        HealthCheckConfig: "HealthCheckConfigTypeDef" = None,
-        HealthCheckCustomConfig: "HealthCheckCustomConfigTypeDef" = None,
-        Tags: List["TagTypeDef"] = None,
-        Type: Literal["HTTP"] = None
+        NamespaceId: str = ...,
+        CreatorRequestId: str = ...,
+        Description: str = ...,
+        DnsConfig: "DnsConfigTypeDef" = ...,
+        HealthCheckConfig: "HealthCheckConfigTypeDef" = ...,
+        HealthCheckCustomConfig: "HealthCheckCustomConfigTypeDef" = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        Type: Literal["HTTP"] = ...
     ) -> CreateServiceResponseTypeDef:
         """
         Creates a service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.create_service)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.create_service)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#create_service)
         """
 
@@ -192,7 +192,7 @@ class ServiceDiscoveryClient(BaseClient):
         """
         Deletes a namespace from the current account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.delete_namespace)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.delete_namespace)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#delete_namespace)
         """
 
@@ -200,7 +200,7 @@ class ServiceDiscoveryClient(BaseClient):
         """
         Deletes a specified service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.delete_service)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.delete_service)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#delete_service)
         """
 
@@ -211,7 +211,7 @@ class ServiceDiscoveryClient(BaseClient):
         Deletes the Amazon Route 53 DNS records and health check, if any, that Cloud Map
         created for the specified instance.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.deregister_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.deregister_instance)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#deregister_instance)
         """
 
@@ -220,29 +220,29 @@ class ServiceDiscoveryClient(BaseClient):
         *,
         NamespaceName: str,
         ServiceName: str,
-        MaxResults: int = None,
-        QueryParameters: Dict[str, str] = None,
-        OptionalParameters: Dict[str, str] = None,
-        HealthStatus: HealthStatusFilterType = None
+        MaxResults: int = ...,
+        QueryParameters: Mapping[str, str] = ...,
+        OptionalParameters: Mapping[str, str] = ...,
+        HealthStatus: HealthStatusFilterType = ...
     ) -> DiscoverInstancesResponseTypeDef:
         """
         Discovers registered instances for a specified namespace and service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.discover_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.discover_instances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#discover_instances)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#generate_presigned_url)
         """
 
@@ -250,7 +250,7 @@ class ServiceDiscoveryClient(BaseClient):
         """
         Gets information about a specified instance.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.get_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.get_instance)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#get_instance)
         """
 
@@ -258,15 +258,15 @@ class ServiceDiscoveryClient(BaseClient):
         self,
         *,
         ServiceId: str,
-        Instances: List[str] = None,
-        MaxResults: int = None,
-        NextToken: str = None
+        Instances: Sequence[str] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> GetInstancesHealthStatusResponseTypeDef:
         """
         Gets the current health status (`Healthy` , `Unhealthy` , or `Unknown` ) of one
         or more instances that are associated with a specified service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.get_instances_health_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.get_instances_health_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#get_instances_health_status)
         """
 
@@ -274,7 +274,7 @@ class ServiceDiscoveryClient(BaseClient):
         """
         Gets information about a namespace.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.get_namespace)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.get_namespace)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#get_namespace)
         """
 
@@ -283,7 +283,7 @@ class ServiceDiscoveryClient(BaseClient):
         Gets information about any operation that returns an operation ID in the
         response, such as a `CreateService` request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.get_operation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.get_operation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#get_operation)
         """
 
@@ -291,62 +291,62 @@ class ServiceDiscoveryClient(BaseClient):
         """
         Gets the settings for a specified service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.get_service)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.get_service)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#get_service)
         """
 
     def list_instances(
-        self, *, ServiceId: str, NextToken: str = None, MaxResults: int = None
+        self, *, ServiceId: str, NextToken: str = ..., MaxResults: int = ...
     ) -> ListInstancesResponseTypeDef:
         """
         Lists summary information about the instances that you registered by using a
         specified service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.list_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.list_instances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#list_instances)
         """
 
     def list_namespaces(
         self,
         *,
-        NextToken: str = None,
-        MaxResults: int = None,
-        Filters: List["NamespaceFilterTypeDef"] = None
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        Filters: Sequence["NamespaceFilterTypeDef"] = ...
     ) -> ListNamespacesResponseTypeDef:
         """
         Lists summary information about the namespaces that were created by the current
         account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.list_namespaces)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.list_namespaces)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#list_namespaces)
         """
 
     def list_operations(
         self,
         *,
-        NextToken: str = None,
-        MaxResults: int = None,
-        Filters: List["OperationFilterTypeDef"] = None
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        Filters: Sequence["OperationFilterTypeDef"] = ...
     ) -> ListOperationsResponseTypeDef:
         """
         Lists operations that match the criteria that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.list_operations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.list_operations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#list_operations)
         """
 
     def list_services(
         self,
         *,
-        NextToken: str = None,
-        MaxResults: int = None,
-        Filters: List["ServiceFilterTypeDef"] = None
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        Filters: Sequence["ServiceFilterTypeDef"] = ...
     ) -> ListServicesResponseTypeDef:
         """
         Lists summary information for all the services that are associated with one or
         more specified namespaces.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.list_services)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.list_services)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#list_services)
         """
 
@@ -354,7 +354,7 @@ class ServiceDiscoveryClient(BaseClient):
         """
         Lists tags for the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#list_tags_for_resource)
         """
 
@@ -363,40 +363,40 @@ class ServiceDiscoveryClient(BaseClient):
         *,
         ServiceId: str,
         InstanceId: str,
-        Attributes: Dict[str, str],
-        CreatorRequestId: str = None
+        Attributes: Mapping[str, str],
+        CreatorRequestId: str = ...
     ) -> RegisterInstanceResponseTypeDef:
         """
         Creates or updates one or more records and, optionally, creates a health check
         based on the settings in a specified service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.register_instance)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.register_instance)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#register_instance)
         """
 
-    def tag_resource(self, *, ResourceARN: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
         """
         Adds one or more tags to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceARN: str, TagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, ResourceARN: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Removes one or more tags from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#untag_resource)
         """
 
     def update_http_namespace(
-        self, *, Id: str, Namespace: "HttpNamespaceChangeTypeDef", UpdaterRequestId: str = None
+        self, *, Id: str, Namespace: "HttpNamespaceChangeTypeDef", UpdaterRequestId: str = ...
     ) -> UpdateHttpNamespaceResponseTypeDef:
         """
         Updates an HTTP namespace.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.update_http_namespace)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.update_http_namespace)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#update_http_namespace)
         """
 
@@ -407,31 +407,27 @@ class ServiceDiscoveryClient(BaseClient):
         Submits a request to change the health status of a custom health check to
         healthy or unhealthy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.update_instance_custom_health_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.update_instance_custom_health_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#update_instance_custom_health_status)
         """
 
     def update_private_dns_namespace(
-        self,
-        *,
-        Id: str,
-        Namespace: "PrivateDnsNamespaceChangeTypeDef",
-        UpdaterRequestId: str = None
+        self, *, Id: str, Namespace: "PrivateDnsNamespaceChangeTypeDef", UpdaterRequestId: str = ...
     ) -> UpdatePrivateDnsNamespaceResponseTypeDef:
         """
         Updates a private DNS namespace.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.update_private_dns_namespace)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.update_private_dns_namespace)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#update_private_dns_namespace)
         """
 
     def update_public_dns_namespace(
-        self, *, Id: str, Namespace: "PublicDnsNamespaceChangeTypeDef", UpdaterRequestId: str = None
+        self, *, Id: str, Namespace: "PublicDnsNamespaceChangeTypeDef", UpdaterRequestId: str = ...
     ) -> UpdatePublicDnsNamespaceResponseTypeDef:
         """
         Updates a public DNS namespace.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.update_public_dns_namespace)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.update_public_dns_namespace)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#update_public_dns_namespace)
         """
 
@@ -443,34 +439,34 @@ class ServiceDiscoveryClient(BaseClient):
         for existing `DnsRecords` configurations * Add, update, or delete
         `HealthCheckConfig` for a specified service .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Client.update_service)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Client.update_service)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/client.html#update_service)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_instances"]) -> ListInstancesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Paginator.ListInstances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Paginator.ListInstances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/paginators.html#listinstancespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_namespaces"]) -> ListNamespacesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Paginator.ListNamespaces)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Paginator.ListNamespaces)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/paginators.html#listnamespacespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_operations"]) -> ListOperationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Paginator.ListOperations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Paginator.ListOperations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/paginators.html#listoperationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_services"]) -> ListServicesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.107/reference/services/servicediscovery.html#ServiceDiscovery.Paginator.ListServices)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/servicediscovery.html#ServiceDiscovery.Paginator.ListServices)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_servicediscovery/paginators.html#listservicespaginator)
         """
