@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     CustomHealthStatusType,
@@ -140,7 +140,7 @@ _OptionalCreateHttpNamespaceRequestRequestTypeDef = TypedDict(
     {
         "CreatorRequestId": str,
         "Description": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -173,7 +173,7 @@ _OptionalCreatePrivateDnsNamespaceRequestRequestTypeDef = TypedDict(
     {
         "CreatorRequestId": str,
         "Description": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "Properties": "PrivateDnsNamespacePropertiesTypeDef",
     },
     total=False,
@@ -206,7 +206,7 @@ _OptionalCreatePublicDnsNamespaceRequestRequestTypeDef = TypedDict(
     {
         "CreatorRequestId": str,
         "Description": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "Properties": "PublicDnsNamespacePropertiesTypeDef",
     },
     total=False,
@@ -243,7 +243,7 @@ _OptionalCreateServiceRequestRequestTypeDef = TypedDict(
         "DnsConfig": "DnsConfigTypeDef",
         "HealthCheckConfig": "HealthCheckConfigTypeDef",
         "HealthCheckCustomConfig": "HealthCheckCustomConfigTypeDef",
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "Type": Literal["HTTP"],
     },
     total=False,
@@ -313,8 +313,8 @@ _OptionalDiscoverInstancesRequestRequestTypeDef = TypedDict(
     "_OptionalDiscoverInstancesRequestRequestTypeDef",
     {
         "MaxResults": int,
-        "QueryParameters": Dict[str, str],
-        "OptionalParameters": Dict[str, str],
+        "QueryParameters": Mapping[str, str],
+        "OptionalParameters": Mapping[str, str],
         "HealthStatus": HealthStatusFilterType,
     },
     total=False,
@@ -338,14 +338,14 @@ DiscoverInstancesResponseTypeDef = TypedDict(
 DnsConfigChangeTypeDef = TypedDict(
     "DnsConfigChangeTypeDef",
     {
-        "DnsRecords": List["DnsRecordTypeDef"],
+        "DnsRecords": Sequence["DnsRecordTypeDef"],
     },
 )
 
 _RequiredDnsConfigTypeDef = TypedDict(
     "_RequiredDnsConfigTypeDef",
     {
-        "DnsRecords": List["DnsRecordTypeDef"],
+        "DnsRecords": Sequence["DnsRecordTypeDef"],
     },
 )
 _OptionalDnsConfigTypeDef = TypedDict(
@@ -404,7 +404,7 @@ _RequiredGetInstancesHealthStatusRequestRequestTypeDef = TypedDict(
 _OptionalGetInstancesHealthStatusRequestRequestTypeDef = TypedDict(
     "_OptionalGetInstancesHealthStatusRequestRequestTypeDef",
     {
-        "Instances": List[str],
+        "Instances": Sequence[str],
         "MaxResults": int,
         "NextToken": str,
     },
@@ -595,7 +595,7 @@ ListNamespacesRequestRequestTypeDef = TypedDict(
     {
         "NextToken": str,
         "MaxResults": int,
-        "Filters": List["NamespaceFilterTypeDef"],
+        "Filters": Sequence["NamespaceFilterTypeDef"],
     },
     total=False,
 )
@@ -614,7 +614,7 @@ ListOperationsRequestRequestTypeDef = TypedDict(
     {
         "NextToken": str,
         "MaxResults": int,
-        "Filters": List["OperationFilterTypeDef"],
+        "Filters": Sequence["OperationFilterTypeDef"],
     },
     total=False,
 )
@@ -633,7 +633,7 @@ ListServicesRequestRequestTypeDef = TypedDict(
     {
         "NextToken": str,
         "MaxResults": int,
-        "Filters": List["ServiceFilterTypeDef"],
+        "Filters": Sequence["ServiceFilterTypeDef"],
     },
     total=False,
 )
@@ -666,7 +666,7 @@ _RequiredNamespaceFilterTypeDef = TypedDict(
     "_RequiredNamespaceFilterTypeDef",
     {
         "Name": Literal["TYPE"],
-        "Values": List[str],
+        "Values": Sequence[str],
     },
 )
 _OptionalNamespaceFilterTypeDef = TypedDict(
@@ -726,7 +726,7 @@ _RequiredOperationFilterTypeDef = TypedDict(
     "_RequiredOperationFilterTypeDef",
     {
         "Name": OperationFilterNameType,
-        "Values": List[str],
+        "Values": Sequence[str],
     },
 )
 _OptionalOperationFilterTypeDef = TypedDict(
@@ -855,7 +855,7 @@ _RequiredRegisterInstanceRequestRequestTypeDef = TypedDict(
     {
         "ServiceId": str,
         "InstanceId": str,
-        "Attributes": Dict[str, str],
+        "Attributes": Mapping[str, str],
     },
 )
 _OptionalRegisterInstanceRequestRequestTypeDef = TypedDict(
@@ -920,7 +920,7 @@ _RequiredServiceFilterTypeDef = TypedDict(
     "_RequiredServiceFilterTypeDef",
     {
         "Name": Literal["NAMESPACE_ID"],
-        "Values": List[str],
+        "Values": Sequence[str],
     },
 )
 _OptionalServiceFilterTypeDef = TypedDict(
@@ -976,7 +976,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -992,7 +992,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
